@@ -572,11 +572,11 @@ add_gtk_timeout()
 	timerclear(&tv);
 	tv.tv_usec = 50000;
 
-	if (!timeout_initialized(&gtk_ev))
-		timeout_set(&gtk_ev, gtk_cb, NULL);
+	if (!evtimer_initialized(&gtk_ev))
+		evtimer_set(&gtk_ev, gtk_cb, NULL);
 
 	if (!quit)
-		timeout_add(&gtk_ev, &tv);
+		evtimer_add(&gtk_ev, &tv);
 }
 
 void
@@ -724,9 +724,9 @@ signal_cb(void)
 
 	/* Restart the process */
 	if (TAILQ_FIRST(&filelist)) {
-		timeout_set(&start_ev, delayed_start, NULL);
+		evtimer_set(&start_ev, delayed_start, NULL);
 		timerclear(&tv);
-		timeout_add(&start_ev, &tv);
+		evtimer_add(&start_ev, &tv);
 	}
 
 	return (0);
@@ -796,7 +796,7 @@ stegdetect_start(void)
 		if (dup2(pstderr[1], fileno(stderr)) == -1)
 			_exit(1);
 
-		execlp("stegdetect", "stegdetect", which, sens, NULL);
+		execlp("stegdetect", "stegdetect", which, sens, (void *)0);
 
 		_exit(1);
 	}
